@@ -126,6 +126,7 @@ class OpenPYXLReader(FileHandler):
         data = data[: last_row_with_data + 1]
         data = self.__read_only_fix(data, version, is_readonly)
         df = self.convert_data(data)
+        data.clear()
 
         if not df.empty and handler:
             row_number -= 1
@@ -283,6 +284,7 @@ class ODFReader(FileHandler):
 
         table = self.__fix_table(table)
         df = self.convert_data(table)
+        table.clear()
 
         if not df.empty and handler:
             row_number -= 1
@@ -448,6 +450,7 @@ class XLRDReader(FileHandler):
             row_number += 1
 
         df = self.convert_data(data)
+        data.clear()
 
         if not df.empty and handler:
             row_number -= 1
@@ -558,6 +561,7 @@ class PYXLSBReader(FileHandler):
             row_number += 1
 
         df = self.convert_data(data)
+        data.clear()
 
         if not df.empty and handler:
             row_number -= 1
